==> apache-doris-2.0.15.1-src.tar.gz: apache-doris-2.0.15.1-src/docs/en/community/team.md <==
---
{
    "title": "Doris Team",
    "language": "en"
}
---

<!-- 
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# PMC Members & Committers

We'd like to thank the following committers to the Apache Doris project who have helped get the project to where it is today. This list might be stale, the canonical list is located on [Apache's website](https://people.apache.org/committers-by-project.html#doris).

## PMC (17)

| Apache ID                                                    | Github Username       | Public Name        |
| :----------------------------------------------------------- | :------------------ | :------------ |
| [lingbin](https://people.apache.org/committer-index.html#lingbin) | lingbin             | Bin Ling      |
| [wangbo](https://people.apache.org/committer-index.html#wangbo) | wangbo              | Bo Wang       |
| [caiconghui](https://people.apache.org/committer-index.html#caiconghui) | caiconghui          | Conghui Cai   |
| [gaodayue](https://people.apache.org/committer-index.html#gaodayue) | gaodayue            | Dayue Gao     |
| [lide](https://people.apache.org/committer-index.html#lide)  | lide-reed, doris-ci | De Li         |
| [yiguolei](https://people.apache.org/committer-index.html#yiguolei) | yiguolei         | Guolei Yi      |
| [chenhao](https://people.apache.org/committer-index.html#chenhao) | chenhao7253886      | Hao Chen      |
| [lihaopeng](https://people.apache.org/committer-index.html#lihaopeng) | HappenLee           | Haopeng Li    |
| [jiafengzheng](https://people.apache.org/committer-index.html#jiafengzheng) | hf200012            | Jiafeng Zhang |
| [lingmiao](https://people.apache.org/committer-index.html#lingmiao) | EmmyMiao87          | Ling Miao     |
| [wenming](https://people.apache.org/committer-index.html#wenming) | moonming      | Ming Wen          |
| [morningman](https://people.apache.org/committer-index.html#morningman) | morningman          | Mingyu Chen   |
| [maruyue](https://people.apache.org/committer-index.html#maruyue) | maruyue                    | Ruyue Ma      |
| [ningjiang](https://people.apache.org/committer-index.html#ningjiang) | WillemJiang   | Willem Ning Jiang |
| [dataroaring](https://people.apache.org/committer-index.html#dataroaring) | dataroaring | Yongqiang Yang   |
| [yangzhg](https://people.apache.org/committer-index.html#yangzhg) | yangzhg             | Zhengguo Yang |
| [weizuo](https://people.apache.org/committer-index.html#weizuo) | weizuo93            | Zuo Wei       |

## Committers (52)

(the listing excludes PMC members above)

| Apache ID                                                    | Github Username    | Public Name         |
| :----------------------------------------------------------- | :--------------- | :------------- |
| [lichaoyong](https://people.apache.org/committer-index.html#lichaoyong) | chaoyli             | Chaoyong Li   |
| [starocean999](https://people.apache.org/committer-index.html#starocean999)    | starocean999 | Chi Li |
| [zhangchen](https://people.apache.org/committer-index.html#zhangchen) | zhannngchen                | Chen Zhang     |
| [zhaoc](https://people.apache.org/committer-index.html#zhaoc) | imay                | Chun Zhao     |
| [adonisling](https://people.apache.org/committer-index.html#adonisling) | adonis0147             | Cong Ling   |
| [diwu](https://people.apache.org/committer-index.html#diwu)  | JNSimba          | Di Wu          |
| [liuhangyuan](https://people.apache.org/committer-index.html#liuhangyuan) | HangyuanLiu         | Hangyuan Liu  |
| [huajianlan](https://people.apache.org/committer-index.html#huajianlan) | 924060929        | Huajian Lan    |
| [huangwei](https://people.apache.org/committer-index.html#huangwei) | vagetablechicken | Huang Wei      |
| [jianliangqi](https://people.apache.org/committer-index.html#jianliangqi) | qidaye           | Jianliang Qi   |
| [jakevin](https://people.apache.org/committer-index.html#jakevin)    | jackwener | Jie Wen |
| [kangkaisen](https://people.apache.org/committer-index.html#kangkaisen) | kangkaisen          | Kaisen Kang   |
| [kangpinghuang](https://people.apache.org/committer-index.html#kangpinghuang) | kangpinghuang    | Kangping Huang |
| [liulijia](https://people.apache.org/committer-index.html#liulijia) | liutang123       | Lijia Liu      |
| [linzhongcheng](https://people.apache.org/committer-index.html#linzhongcheng) | chenlinzhong       | LinZhong Chen      |
| [stalary](https://people.apache.org/committer-index.html#stalary)    | stalary | Rongqian Li |
| [shaofengshi](https://people.apache.org/committer-index.html#shaofengshi) | shaofengshi     | Shaofeng Shi     |
| [sijie](https://people.apache.org/committer-index.html#sijie) | sijie               | Sijie Guo     |
| [yintao](https://people.apache.org/committer-index.html#yintao) | yinzhijian               | Tao Yin    |
| [gabriellee](https://people.apache.org/committer-index.html#gabriellee)    | Gabriel39 | Wenqiang Li |
| [morrysnow](https://people.apache.org/committer-index.html#morrysnow)    | morrySnow  | Wenxin Zhang |
| [panxiaolei](https://people.apache.org/committer-index.html#panxiaolei) | BiteTheDDDDt       | Xiaolei Pan      |
| [cambyzju](https://people.apache.org/committer-index.html#cambyzju)    | cambyzju | Xiaoli Zhu  |
| [pengxiangyu](https://people.apache.org/committer-index.html#pengxiangyu)    | pengxiangyu | Xiangyu Peng |
| [weixiang](https://people.apache.org/committer-index.html#weixiang) | spaces-X            | Xiang Wei     |
| [zouxinyi](https://people.apache.org/committer-index.html#zouxinyi) | xinyiZzz               | Xinyi Zou     |
| [wangxixu](https://people.apache.org/committer-index.html#wangxixu) | xinghuayu007     | Xixu Wang      |
| [xuyang](https://people.apache.org/committer-index.html#xuyang) | xy720            | Yang Xu        |
| [laiyingchun](https://people.apache.org/committer-index.html#laiyingchun) | acelyc111        | Yingchun Lai   |
| [wyf](https://people.apache.org/committer-index.html#wyf)    | wuyunfeng        | Yunfeng Wu     |
| [luozenglin](https://people.apache.org/committer-index.html#luozenglin)    | luozenglin | Zenglin Luo |
| [zenoyang](https://people.apache.org/committer-index.html#zenoyang)    | zenoyang  | Zeno Yang     |
| [zshao](https://people.apache.org/committer-index.html#zshao)    | zshao | Zheng Shao |
| [luzhijing](https://people.apache.org/committer-index.html#luzhijing)    | luzhijing | Zhijing Lu |
| [englefly](https://people.apache.org/committer-index.html#englefly)    | englefly | Zhou Minghong |

## Contributors

[All Contributors](https://github.com/apache/doris/graphs/contributors)

==> apache-doris-2.1.11-rc01-src.tar.gz: apache-doris-2.1.11-rc01-src/docs/en/community/team.md <==
---
{
    "title": "Doris Team",
    "language": "en"
}
---

<!-- 
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# PMC Members & Committers

We'd like to thank the following committers to the Apache Doris project who have helped get the project to where it is today. This list might be stale, the canonical list is located on [Apache's website](https://people.apache.org/committers-by-project.html#doris).

## PMC (22)

| Apache ID                                                    | Github Username       | Public Name        |
| :----------------------------------------------------------- | :------------------ | :------------ |
| [lingbin](https://people.apache.org/committer-index.html#lingbin) | lingbin             | Bin Ling      |
| [wangbo](https://people.apache.org/committer-index.html#wangbo) | wangbo              | Bo Wang       |
| [caiconghui](https://people.apache.org/committer-index.html#caiconghui) | caiconghui          | Conghui Cai   |
| [gaodayue](https://people.apache.org/committer-index.html#gaodayue) | gaodayue            | Dayue Gao     |
| [lide](https://people.apache.org/committer-index.html#lide)  | lide-reed, doris-ci | De Li         |
| [yiguolei](https://people.apache.org/committer-index.html#yiguolei) | yiguolei         | Guolei Yi      |
| [chenhao](https://people.apache.org/committer-index.html#chenhao) | chenhao7253886      | Hao Chen      |
| [lihaopeng](https://people.apache.org/committer-index.html#lihaopeng) | HappenLee           | Haopeng Li    |
| [jiafengzheng](https://people.apache.org/committer-index.html#jiafengzheng) | hf200012            | Jiafeng Zhang |
| [lingmiao](https://people.apache.org/committer-index.html#lingmiao) | EmmyMiao87          | Ling Miao     |
| [wenming](https://people.apache.org/committer-index.html#wenming) | moonming      | Ming Wen          |
| [morningman](https://people.apache.org/committer-index.html#morningman) | morningman          | Mingyu Chen   |
| [maruyue](https://people.apache.org/committer-index.html#maruyue) | maruyue                    | Ruyue Ma      |
| [ningjiang](https://people.apache.org/committer-index.html#ningjiang) | WillemJiang   | Willem Ning Jiang |
| [dataroaring](https://people.apache.org/committer-index.html#dataroaring) | dataroaring | Yongqiang Yang   |
| [yangzhg](https://people.apache.org/committer-index.html#yangzhg) | yangzhg             | Zhengguo Yang |
| [weizuo](https://people.apache.org/committer-index.html#weizuo) | weizuo93            | Zuo Wei       |
| [diwu](https://people.apache.org/committer-index.html#diwu) | JNSimba            | Di Wu       |
| [jakevin](https://people.apache.org/committer-index.html#jakevin) | jackwener            | Jie Wen       |
| [kxiao](https://people.apache.org/committer-index.html#kxiao) | xiaokang            | Kang Xiao       |
| [liulijia](https://people.apache.org/committer-index.html#liulijia) | liutang123            | Lijia Liu       |
| [morrysnow](https://people.apache.org/committer-index.html#morrysnow) | MorrySnow            | Wenxin Zhang       |

## Committers (45)

(the listing excludes PMC members above)

| Apache ID                                                    | Github Username    | Public Name         |
| :----------------------------------------------------------- | :--------------- | :------------- |
| [lichaoyong](https://people.apache.org/committer-index.html#lichaoyong) | chaoyli             | Chaoyong Li   |
| [starocean999](https://people.apache.org/committer-index.html#starocean999)    | starocean999 | Chi Li |
| [zhangchen](https://people.apache.org/committer-index.html#zhangchen) | zhannngchen                | Chen Zhang     |
| [zhaoc](https://people.apache.org/committer-index.html#zhaoc) | imay                | Chun Zhao     |
| [adonisling](https://people.apache.org/committer-index.html#adonisling) | adonis0147             | Cong Ling   |
| [liuhangyuan](https://people.apache.org/committer-index.html#liuhangyuan) | HangyuanLiu         | Hangyuan Liu  |
| [huajianlan](https://people.apache.org/committer-index.html#huajianlan) | 924060929        | Huajian Lan    |
| [huangwei](https://people.apache.org/committer-index.html#huangwei) | vagetablechicken | Huang Wei      |
| [jianliangqi](https://people.apache.org/committer-index.html#jianliangqi) | qidaye           | Jianliang Qi   |
| [kangkaisen](https://people.apache.org/committer-index.html#kangkaisen) | kangkaisen          | Kaisen Kang   |
| [kangpinghuang](https://people.apache.org/committer-index.html#kangpinghuang) | kangpinghuang    | Kangping Huang |
| [liulijia](https://people.apache.org/committer-index.html#liulijia) | liutang123       | Lijia Liu      |
| [linzhongcheng](https://people.apache.org/committer-index.html#linzhongcheng) | chenlinzhong       | LinZhong Chen      |
| [stalary](https://people.apache.org/committer-index.html#stalary)    | stalary | Rongqian Li |
| [shaofengshi](https://people.apache.org/committer-index.html#shaofengshi) | shaofengshi     | Shaofeng Shi     |
| [sijie](https://people.apache.org/committer-index.html#sijie) | sijie               | Sijie Guo     |
| [yintao](https://people.apache.org/committer-index.html#yintao) | yinzhijian               | Tao Yin    |
| [gabriellee](https://people.apache.org/committer-index.html#gabriellee)    | Gabriel39 | Wenqiang Li |
| [panxiaolei](https://people.apache.org/committer-index.html#panxiaolei) | BiteTheDDDDt       | Xiaolei Pan      |
| [cambyzju](https://people.apache.org/committer-index.html#cambyzju)    | cambyzju | Xiaoli Zhu  |
| [pengxiangyu](https://people.apache.org/committer-index.html#pengxiangyu)    | pengxiangyu | Xiangyu Peng |
| [weixiang](https://people.apache.org/committer-index.html#weixiang) | spaces-X            | Xiang Wei     |
| [zouxinyi](https://people.apache.org/committer-index.html#zouxinyi) | xinyiZzz               | Xinyi Zou     |
| [wangxixu](https://people.apache.org/committer-index.html#wangxixu) | xinghuayu007     | Xixu Wang      |
| [xuyang](https://people.apache.org/committer-index.html#xuyang) | xy720            | Yang Xu        |
| [laiyingchun](https://people.apache.org/committer-index.html#laiyingchun) | acelyc111        | Yingchun Lai   |
| [wyf](https://people.apache.org/committer-index.html#wyf)    | wuyunfeng        | Yunfeng Wu     |
| [luozenglin](https://people.apache.org/committer-index.html#luozenglin)    | luozenglin | Zenglin Luo |
| [zenoyang](https://people.apache.org/committer-index.html#zenoyang)    | zenoyang  | Zeno Yang     |
| [zshao](https://people.apache.org/committer-index.html#zshao)    | zshao | Zheng Shao |
| [luzhijing](https://people.apache.org/committer-index.html#luzhijing)    | luzhijing | Zhijing Lu |
| [englefly](https://people.apache.org/committer-index.html#englefly)    | englefly | Zhou Minghong |
| [yangbowen](https://people.apache.org/committer-index.html#yangbowen)    | GoGoWen | Bowen Yang |
| [kirs](https://people.apache.org/committer-index.html#kirs)    | CalvinKirs | Calvin Kirs |
| [plat1ko](https://people.apache.org/committer-index.html#plat1ko)    | plat1ko | 	Cheng Yuxuan |
| [eldenmoon](https://people.apache.org/committer-index.html#eldenmoon)    | eldenmoon | 		Hangyu Li |
| [jacktengg](https://people.apache.org/committer-index.html#jacktengg)    | jacktengg | 			Jack Teng |
| [mrhhsg](https://people.apache.org/committer-index.html#mrhhsg)    | mrhhsg | Jerry Hu |
| [lijibing](https://people.apache.org/committer-index.html#lijibing)    | Jibing-Li | Jibing Li |
| [dutyu](https://people.apache.org/committer-index.html#dutyu)    | dutyu | 	Xiangyu Wang |
| [ashingau](https://people.apache.org/committer-index.html#ashingau)    | AshinGau | 	Xin Gao |
| [liaoxin](https://people.apache.org/committer-index.html#liaoxin)    | liaoxin01 | 	Xin Liao |
| [nextdreamblue](https://people.apache.org/committer-index.html#nextdreamblue)    | nextdreamblue | 	Xuewei Zhang |
| [zykkk](https://people.apache.org/committer-index.html#zykkk)    | zy-kkk | 		Yongkang Zhong |
| [carlmartin](https://people.apache.org/committer-index.html#carlmartin)    | SaintBacchus |  Zhaowei Huang |

## Contributors

[All Contributors](https://github.com/apache/doris/graphs/contributors)
